@@ -42,7 +42,7 @@
 #include <gvfsjobmount.h>
 #include <gvfsjobopenforread.h>
 #include <gvfsjobopenforwrite.h>
-#include <gdbusutils.h>
+#include <gvfsdbusutils.h>
 
 enum {
   PROP_0
@@ -999,10 +999,25 @@ peer_to_peer_filter_func (DBusConnection *conn,
 			  DBusMessage    *message,
 			  gpointer        data)
 {
+  GVfsDaemon *daemon = data;
+
   if (dbus_message_is_signal (message,
 			      DBUS_INTERFACE_LOCAL,
 			      "Disconnected"))
     {
+      GList *l;
+
+      g_mutex_lock (daemon->lock);
+      for (l = daemon->jobs; l != NULL; l = l->next)
+        {
+          GVfsJob *job = l->data;
+          
+          if (G_VFS_IS_JOB_DBUS (job) &&
+              G_VFS_JOB_DBUS (job)->connection == conn)
+            g_vfs_job_cancel (job);
+        }
+      g_mutex_unlock (daemon->lock);
+
       /* The peer-to-peer connection was disconnected */
       dbus_connection_unref (conn);
       return DBUS_HANDLER_RESULT_HANDLED;
@@ -1057,7 +1072,7 @@ g_vfs_daemon_initiate_mount (GVfsDaemon *daemon,
   obj_path = g_strdup_printf ("/org/gtk/vfs/mount/%d", ++daemon->mount_counter);
   backend = g_object_new (backend_type,
 			  "daemon", daemon,
-			  "object_path", obj_path,
+			  "object-path", obj_path,
 			  NULL);
   g_free (obj_path);
 
@@ -1066,6 +1081,7 @@ g_vfs_daemon_initiate_mount (GVfsDaemon *daemon,
 
   job = g_vfs_job_mount_new (mount_spec, mount_source, is_automount, request, backend);
   g_vfs_daemon_queue_job (daemon, job);
+  g_object_unref (job);
 }
 
 /**
