@@ -32,7 +32,7 @@
 #include <dbus/dbus.h>
 #include <glib/gi18n.h>
 #include "gvfsjobmove.h"
-#include "gdbusutils.h"
+#include "gvfsdbusutils.h"
 #include "gvfsdaemonprotocol.h"
 
 G_DEFINE_TYPE (GVfsJobMove, g_vfs_job_move, G_VFS_TYPE_JOB_DBUS)
@@ -122,22 +122,21 @@ g_vfs_job_move_new (DBusConnection *connection,
   return G_VFS_JOB (job);
 }
 
-static void
-progress_callback (goffset current_num_bytes,
-		   goffset total_num_bytes,
-		   gpointer user_data)
+void
+g_vfs_job_move_progress_callback (goffset current_num_bytes,
+				  goffset total_num_bytes,
+				  GVfsJob *job)
 {
-  GVfsJob *job = G_VFS_JOB (user_data);
   GVfsJobDBus *dbus_job = G_VFS_JOB_DBUS (job);
   GVfsJobMove *op_job = G_VFS_JOB_MOVE (job);
   dbus_uint64_t current_dbus, total_dbus;
   DBusMessage *message;
 
-  g_print ("progress_callback %d/%d\n", (int)current_num_bytes, (int)total_num_bytes);
+  g_debug ("progress_callback %" G_GOFFSET_FORMAT "/%" G_GOFFSET_FORMAT "\n", current_num_bytes, total_num_bytes);
 
   if (op_job->callback_obj_path == NULL)
     return;
-  
+
   message =
     dbus_message_new_method_call (dbus_message_get_sender (dbus_job->message),
 				  op_job->callback_obj_path,
@@ -175,7 +174,7 @@ run (GVfsJob *job)
 	       op_job->source,
 	       op_job->destination,
 	       op_job->flags,
-	       progress_callback,
+	       (GFileProgressCallback)g_vfs_job_move_progress_callback,
 	       job);
 }
 
@@ -193,7 +192,7 @@ try (GVfsJob *job)
 			  op_job->source,
 			  op_job->destination,
 			  op_job->flags,
-			  progress_callback,
+			  (GFileProgressCallback)g_vfs_job_move_progress_callback,
 			  job);
 }
 
